@@ -158,12 +158,7 @@ class IQOption:
                 isOpen.append(result)
 
             
-        df = pd.DataFrame(isOpen)
-        keys = list(OP_code.ACTIVES.keys())
-
-        # Crear una máscara booleana
-        mask = df['asset'].isin(keys)
-        return df[mask]
+        return pd.DataFrame(isOpen)
 
     def payout(self, symbol, turbo=None):
         if turbo:
